@@ -11,7 +11,7 @@ my $config = My::Config->new;
 FFI::Build->new(
   'test',
   source   => ['t/ffi/*.c'],
-  verbose  => (!!$ENV{V} ? 2 : 1),
+  verbose  => 1,
   alien    => [$config->build_config->get('alien')->{class}],
   cflags   => ['-Iinclude'],
   dir      => 't/ffi',
