@@ -14,7 +14,7 @@ use Capture::Tiny ();
 use File::Path ();
 
 # ABSTRACT: Build shared libraries for use with FFI
-our $VERSION = '1.90_02'; # TRIAL VERSION
+our $VERSION = '1.91_01'; # TRIAL VERSION
 
 # Platypus-Man,
 # Platypus-Man,
@@ -73,6 +73,8 @@ sub new
   my $verbose   = $self->{verbose}   = $args{verbose}   || 0;
   my $export    = $self->{export}    = $args{export}    || [];
 
+  $self->{verbose} = $verbose = 2 if $ENV{V};
+
   if(defined $args{cflags})
   {
     my @flags = ref $args{cflags} ? @{ $args{cflags} } : $self->platform->shellwords($args{cflags});
@@ -364,7 +366,7 @@ FFI::Build - Build shared libraries for use with FFI
 
 =head1 VERSION
 
-version 1.90_02
+version 1.91_01
 
 =head1 SYNOPSIS
 
@@ -477,6 +479,9 @@ Output the complete commands run verbatim.
 
 =back
 
+If the environment variable C<V> is set to a true value then the verbosity will be set to C<2> regardless
+of what is passed in.
+
 =back
 
 =head1 METHODS
